@@ -3,7 +3,7 @@
 # Copyright 2013 Sebastian Ramacher <sebastian+dev@ramacher.at>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the “Software”), to deal
+# of this software and associated documentation files (the "Software"), to deal
 # in the Software without restriction, including without limitation the rights
 # to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 # copies of the Software, and to permit persons to whom the Software is
@@ -116,7 +116,7 @@ class DiscId(object):
   def webservice_url(self):
     """ The web service URL for info about the CD
 
-    With this url you can retrive information about the CD in XML from the
+    With this url you can retrieve information about the CD in XML from the
     MusicBrainz web service.
     """
 
@@ -261,7 +261,7 @@ def read(device=None, features=None):
   return DiscId(disc)
 
 def put(first, last, sectors, offsets):
-  """ Creates a TOC based on the given offets.
+  """ Creates a TOC based on the given offsets.
 
   Takes the *first* and *last* audio track, as well as the number of
   *sectors* and a list of *offsets* as in :attr:`track_offsets`.
