@@ -3,7 +3,7 @@
 # Copyright 2013 Sebastian Ramacher <sebastian+dev@ramacher.at>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the “Software”), to deal
+# of this software and associated documentation files (the "Software"), to deal
 # in the Software without restriction, including without limitation the rights
 # to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 # copies of the Software, and to permit persons to whom the Software is
@@ -23,19 +23,13 @@
 """ Tests for the libdiscid.compat.discid module
 """
 
-try:
-  import unittest2 as unittest
-except ImportError:
-  import unittest
+from __future__ import unicode_literals
+
+import unittest
 import libdiscid
 from libdiscid.compat import discid
 from libdiscid.compat.discid import DiscError, TOCError
 
-# as long as Python 3.2 is supported, hack around the missing u
-try:
-  u = unicode
-except NameError:
-  u = str
 
 class TestCompatDiscID(unittest.TestCase):
   def test_default_device(self):
@@ -62,7 +56,7 @@ class TestCompatDiscID(unittest.TestCase):
   @unittest.skipIf(libdiscid.FEATURES_MAPPING[libdiscid.FEATURE_READ] not in
                    libdiscid.FEATURES, 'not available on this platform')
   def test_read_fail(self):
-    self.assertRaises(DiscError, discid.read, u('/does/not/exist'))
+    self.assertRaises(DiscError, discid.read, '/does/not/exist')
 
   def test_read_None(self):
     try:
