@@ -3,7 +3,7 @@
 # Copyright 2013 Sebastian Ramacher <sebastian+dev@ramacher.at>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the “Software”), to deal
+# of this software and associated documentation files (the "Software"), to deal
 # in the Software without restriction, including without limitation the rights
 # to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 # copies of the Software, and to permit persons to whom the Software is
@@ -23,19 +23,13 @@
 """ Tests for the libdiscid module
 """
 
-try:
-  import unittest2 as unittest
-except ImportError:
-  import unittest
+from __future__ import unicode_literals
+
+import unittest
 import libdiscid
 import libdiscid.tests.common
 from libdiscid import DiscError
 
-# as long as Python 3.2 is supported, hack around the missing u
-try:
-  u = unicode
-except NameError:
-  u = str
 
 class TestLibDiscId(unittest.TestCase):
   def test_version(self):
@@ -58,7 +52,7 @@ class TestLibDiscId(unittest.TestCase):
   @unittest.skipIf(libdiscid.FEATURES_MAPPING[libdiscid.FEATURE_READ] not in
                    libdiscid.FEATURES, 'not available on this platform')
   def test_read_fail(self):
-    self.assertRaises(DiscError, libdiscid.read, u('/does/not/exist'))
+    self.assertRaises(DiscError, libdiscid.read, '/does/not/exist')
 
   def test_read_None(self):
     try:
@@ -98,11 +92,11 @@ class TestLibDiscId(unittest.TestCase):
     if libdiscid.FEATURES_MAPPING[libdiscid.FEATURE_ISRC] in libdiscid.FEATURES:
       self.assertEqual(len(disc.track_isrcs), 15)
       for read_isrc in disc.track_isrcs:
-        self.assertEqual(read_isrc, u(''))
+        self.assertEqual(read_isrc, '')
 
     # MCN is not available if one calls put
     if libdiscid.FEATURES_MAPPING[libdiscid.FEATURE_MCN] in libdiscid.FEATURES:
-      self.assertEqual(disc.mcn, u(''))
+      self.assertEqual(disc.mcn, '')
 
   def test_put_fail_1(self):
     # !(first < last)
